import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:intl/intl.dart' as intl;

import 'l10n_ar.dart';
import 'l10n_bn.dart';
import 'l10n_en.dart';
import 'l10n_fa.dart';
import 'l10n_fr.dart';
import 'l10n_ur.dart';

/// Callers can lookup localized strings with an instance of AppLocalizations
/// returned by `AppLocalizations.of(context)`.
///
/// Applications need to include `AppLocalizations.delegate()` in their app's
/// `localizationDelegates` list, and the locales they support in the app's
/// `supportedLocales` list. For example:
///
/// ```dart
/// import 'gen_l10n/l10n.dart';
///
/// return MaterialApp(
///   localizationsDelegates: AppLocalizations.localizationsDelegates,
///   supportedLocales: AppLocalizations.supportedLocales,
///   home: MyApplicationHome(),
/// );
/// ```
///
/// ## Update pubspec.yaml
///
/// Please make sure to update your pubspec.yaml to include the following
/// packages:
///
/// ```yaml
/// dependencies:
///   # Internationalization support.
///   flutter_localizations:
///     sdk: flutter
///   intl: any # Use the pinned version from flutter_localizations
///
///   # Rest of dependencies
/// ```
///
/// ## iOS Applications
///
/// iOS applications define key application metadata, including supported
/// locales, in an Info.plist file that is built into the application bundle.
/// To configure the locales supported by your app, you’ll need to edit this
/// file.
///
/// First, open your project’s ios/Runner.xcworkspace Xcode workspace file.
/// Then, in the Project Navigator, open the Info.plist file under the Runner
/// project’s Runner folder.
///
/// Next, select the Information Property List item, select Add Item from the
/// Editor menu, then select Localizations from the pop-up menu.
///
/// Select and expand the newly-created Localizations item then, for each
/// locale your application supports, add a new item and select the locale
/// you wish to add from the pop-up menu in the Value field. This list should
/// be consistent with the languages listed in the AppLocalizations.supportedLocales
/// property.
abstract class AppLocalizations {
  AppLocalizations(String locale) : localeName = intl.Intl.canonicalizedLocale(locale.toString());

  final String localeName;

  static AppLocalizations of(BuildContext context) {
    return Localizations.of<AppLocalizations>(context, AppLocalizations)!;
  }

  static const LocalizationsDelegate<AppLocalizations> delegate = _AppLocalizationsDelegate();

  /// A list of this localizations delegate along with the default localizations
  /// delegates.
  ///
  /// Returns a list of localizations delegates containing this delegate along with
  /// GlobalMaterialLocalizations.delegate, GlobalCupertinoLocalizations.delegate,
  /// and GlobalWidgetsLocalizations.delegate.
  ///
  /// Additional delegates can be added by appending to this list in
  /// MaterialApp. This list does not have to be used at all if a custom list
  /// of delegates is preferred or required.
  static const List<LocalizationsDelegate<dynamic>> localizationsDelegates = <LocalizationsDelegate<dynamic>>[
    delegate,
    GlobalMaterialLocalizations.delegate,
    GlobalCupertinoLocalizations.delegate,
    GlobalWidgetsLocalizations.delegate,
  ];

  /// A list of this localizations delegate's supported locales.
  static const List<Locale> supportedLocales = <Locale>[
    Locale('fa'),
    Locale('ar'),
    Locale('bn'),
    Locale('en'),
    Locale('fr'),
    Locale('ur')
  ];

  /// No description provided for @activate_app_lock.
  ///
  /// In en, this message translates to:
  /// **'Activate App Lock'**
  String get activate_app_lock;

  /// No description provided for @add.
  ///
  /// In en, this message translates to:
  /// **'Add'**
  String get add;

  /// No description provided for @add_day.
  ///
  /// In en, this message translates to:
  /// **'Add Day'**
  String get add_day;

  /// No description provided for @add_days.
  ///
  /// In en, this message translates to:
  /// **'Add Days'**
  String get add_days;

  /// No description provided for @alert.
  ///
  /// In en, this message translates to:
  /// **'ALert'**
  String get alert;

  /// No description provided for @app_lang.
  ///
  /// In en, this message translates to:
  /// **'App Language'**
  String get app_lang;

  /// No description provided for @app_lock.
  ///
  /// In en, this message translates to:
  /// **'App Lock'**
  String get app_lock;

  /// No description provided for @app_lock_default_password.
  ///
  /// In en, this message translates to:
  /// **'Default Password'**
  String get app_lock_default_password;

  /// No description provided for @app_lock_enter_new_password.
  ///
  /// In en, this message translates to:
  /// **'Enter New Password'**
  String get app_lock_enter_new_password;

  /// No description provided for @app_lock_enter_old_password.
  ///
  /// In en, this message translates to:
  /// **'Enter Old Password'**
  String get app_lock_enter_old_password;

  /// No description provided for @app_lock_password_reset_done.
  ///
  /// In en, this message translates to:
  /// **'Password Reset Done'**
  String get app_lock_password_reset_done;

  /// No description provided for @app_lock_reset_password.
  ///
  /// In en, this message translates to:
  /// **'Reset Password'**
  String get app_lock_reset_password;

  /// No description provided for @app_open_msg.
  ///
  /// In en, this message translates to:
  /// **'You haven\'t opened the app for a long time.'**
  String get app_open_msg;

  /// No description provided for @asr.
  ///
  /// In en, this message translates to:
  /// **'Asr'**
  String get asr;

  /// No description provided for @completion_date.
  ///
  /// In en, this message translates to:
  /// **'Completion Date'**
  String get completion_date;

  /// No description provided for @custom_add_period.
  ///
  /// In en, this message translates to:
  /// **'Custom Add Period'**
  String get custom_add_period;

  /// No description provided for @custom_add_prayers.
  ///
  /// In en, this message translates to:
  /// **'Custom Add Prayers'**
  String get custom_add_prayers;

  /// No description provided for @custom_done_period.
  ///
  /// In en, this message translates to:
  /// **'Custom Add Period'**
  String get custom_done_period;

  /// No description provided for @custom_done_prayers.
  ///
  /// In en, this message translates to:
  /// **'Custom Done Prayers'**
  String get custom_done_prayers;

  /// No description provided for @day.
  ///
  /// In en, this message translates to:
  /// **'Day'**
  String get day;

  /// No description provided for @days.
  ///
  /// In en, this message translates to:
  /// **'Days'**
  String get days;

  /// No description provided for @dhuhr.
  ///
  /// In en, this message translates to:
  /// **'Dhuhr'**
  String get dhuhr;

  /// No description provided for @dismiss.
  ///
  /// In en, this message translates to:
  /// **'Dismiss'**
  String get dismiss;

  /// No description provided for @done.
  ///
  /// In en, this message translates to:
  /// **'Done'**
  String get done;

  /// No description provided for @done_day.
  ///
  /// In en, this message translates to:
  /// **'Done Day'**
  String get done_day;

  /// No description provided for @done_days.
  ///
  /// In en, this message translates to:
  /// **'Done Days'**
  String get done_days;

  /// No description provided for @done_prayer.
  ///
  /// In en, this message translates to:
  /// **'Done'**
  String get done_prayer;

  /// No description provided for @enter_password.
  ///
  /// In en, this message translates to:
  /// **'Enter Password'**
  String get enter_password;

  /// No description provided for @fajr.
  ///
  /// In en, this message translates to:
  /// **'Fajr'**
  String get fajr;

  /// No description provided for @fast.
  ///
  /// In en, this message translates to:
  /// **'Fast'**
  String get fast;

  /// No description provided for @ishaa.
  ///
  /// In en, this message translates to:
  /// **'Ishaa'**
  String get ishaa;

  /// No description provided for @maghrib.
  ///
  /// In en, this message translates to:
  /// **'Maghrib'**
  String get maghrib;

  /// No description provided for @make_up_missed_prayers.
  ///
  /// In en, this message translates to:
  /// **'Make up Missed Prayers'**
  String get make_up_missed_prayers;

  /// No description provided for @missed_prayer.
  ///
  /// In en, this message translates to:
  /// **'Missed Prayer'**
  String get missed_prayer;

  /// No description provided for @month.
  ///
  /// In en, this message translates to:
  /// **'Month'**
  String get month;

  /// No description provided for @new_prayer.
  ///
  /// In en, this message translates to:
  /// **'New Prayer'**
  String get new_prayer;

  /// No description provided for @no.
  ///
  /// In en, this message translates to:
  /// **'No'**
  String get no;

  /// No description provided for @no_missed_prayer.
  ///
  /// In en, this message translates to:
  /// **'No Missed Prayer'**
  String get no_missed_prayer;

  /// No description provided for @open_in_google_play.
  ///
  /// In en, this message translates to:
  /// **'Open in Google Play'**
  String get open_in_google_play;

  /// No description provided for @other_settings.
  ///
  /// In en, this message translates to:
  /// **'others'**
  String get other_settings;

  /// No description provided for @periods_done_title.
  ///
  /// In en, this message translates to:
  /// **'Time'**
  String get periods_done_title;

  /// No description provided for @periods_title.
  ///
  /// In en, this message translates to:
  /// **'Add Time'**
  String get periods_title;

  /// No description provided for @prayer_Settings.
  ///
  /// In en, this message translates to:
  /// **'Prayer Settings'**
  String get prayer_Settings;

  /// No description provided for @prayers_done_title.
  ///
  /// In en, this message translates to:
  /// **'Prayers'**
  String get prayers_done_title;

  /// No description provided for @prayers_title.
  ///
  /// In en, this message translates to:
  /// **'Add Prayers'**
  String get prayers_title;

  /// No description provided for @prayers_to_do_per_day.
  ///
  /// In en, this message translates to:
  /// **'Prayers to do a day'**
  String get prayers_to_do_per_day;

  /// No description provided for @qadaa.
  ///
  /// In en, this message translates to:
  /// **'Qadaa'**
  String get qadaa;

  /// No description provided for @remaining_days.
  ///
  /// In en, this message translates to:
  /// **'Remaining Days'**
  String get remaining_days;

  /// No description provided for @reset_everything.
  ///
  /// In en, this message translates to:
  /// **'Reset everything'**
  String get reset_everything;

  /// No description provided for @settings.
  ///
  /// In en, this message translates to:
  /// **'Settings'**
  String get settings;

  /// No description provided for @skip.
  ///
  /// In en, this message translates to:
  /// **'Skip'**
  String get skip;

  /// No description provided for @splash_background.
  ///
  /// In en, this message translates to:
  /// **'Splash Background'**
  String get splash_background;

  /// No description provided for @splash_random_image.
  ///
  /// In en, this message translates to:
  /// **'Random Image'**
  String get splash_random_image;

  /// No description provided for @splash_static_color.
  ///
  /// In en, this message translates to:
  /// **'Static color'**
  String get splash_static_color;

  /// No description provided for @splash_static_image.
  ///
  /// In en, this message translates to:
  /// **'Static Image'**
  String get splash_static_image;

  /// No description provided for @start.
  ///
  /// In en, this message translates to:
  /// **'Start'**
  String get start;

  /// No description provided for @sure_to_reset_everything_msg.
  ///
  /// In en, this message translates to:
  /// **'Are you sure you want to reset everything?'**
  String get sure_to_reset_everything_msg;

  /// No description provided for @today.
  ///
  /// In en, this message translates to:
  /// **'Today'**
  String get today;

  /// No description provided for @ui.
  ///
  /// In en, this message translates to:
  /// **'UI'**
  String get ui;

  /// No description provided for @version.
  ///
  /// In en, this message translates to:
  /// **'Version'**
  String get version;

  /// No description provided for @week.
  ///
  /// In en, this message translates to:
  /// **'Week'**
  String get week;

  /// No description provided for @year.
  ///
  /// In en, this message translates to:
  /// **'Year'**
  String get year;

  /// No description provided for @yes.
  ///
  /// In en, this message translates to:
  /// **'Yes'**
  String get yes;
}

class _AppLocalizationsDelegate extends LocalizationsDelegate<AppLocalizations> {
  const _AppLocalizationsDelegate();

  @override
  Future<AppLocalizations> load(Locale locale) {
    return SynchronousFuture<AppLocalizations>(lookupAppLocalizations(locale));
  }

  @override
  bool isSupported(Locale locale) => <String>['fa', 'ar', 'bn', 'en', 'fr', 'ur'].contains(locale.languageCode);

  @override
  bool shouldReload(_AppLocalizationsDelegate old) => false;
}

AppLocalizations lookupAppLocalizations(Locale locale) {


  // Lookup logic when only language code is specified.
  switch (locale.languageCode) {
    case 'fa': return AppLocalizationsFa();
    case 'ar': return AppLocalizationsAr();
    case 'bn': return AppLocalizationsBn();
    case 'en': return AppLocalizationsEn();
    case 'fr': return AppLocalizationsFr();
    case 'ur': return AppLocalizationsUr();
  }

  throw FlutterError(
    'AppLocalizations.delegate failed to load unsupported locale "$locale". This is likely '
    'an issue with the localizations generation tool. Please file an issue '
    'on GitHub with a reproducible sample app and the gen-l10n configuration '
    'that was used.'
  );
}
